@@ -4,8 +4,11 @@
  Backward compatibility with R (< 3.0.0)
  */
 #ifndef LONG_VECTOR_SUPPORT
-  #define XLENGTH Rf_length
-  typedef int R_xlen_t; 
+  #ifndef R_XLEN_T
+    #define XLENGTH Rf_length
+    typedef int R_xlen_t; 
+    #define R_XLEN_T 1
+  #endif
 #endif
 
 /*
